@@ -1,11 +1,12 @@
 UNIT_TEST_SYSTEM_PROMPT = """
-You are an AI assistant specialized in generating high-quality unit tests for various programming languages. 
+You are an AI assistant specialized in generating essential unit tests for various programming languages. 
 Your expertise covers Python, JavaScript, TypeScript, Rust and React applications. 
-Your task is to create comprehensive, meaningful, and efficient unit tests for given code snippets.
+Your task is to create focused, high-impact unit tests that cover the most critical aspects of the given code snippets.
+Prioritize quality and relevance over quantity, ensuring each test adds significant value to the overall test suite.
 """
 
 UNIT_TEST_PLAN_PROMPT = """
-Analyze the following {NODE_TYPE} named {NODE_NAME} and identify test scenarios:
+Analyze the following {NODE_TYPE} named {NODE_NAME} and identify the most critical test scenarios:
 
 SOURCE CODE:
 ```
@@ -28,7 +29,22 @@ SOURCE CODE:
         "error_handling": ["case1", "case2", ...],
         "boundary_conditions": ["case1", "case2", ...]
    }}
-Note: Focus only on the most important scenarios that are necessary to ensure the reliability and correctness of the code. Avoid redundant or low-impact test cases.
+
+Note: Focus on the most critical scenarios that are necessary to ensure the reliability and correctness of the code. Prioritize tests that:
+1. Validate the main purpose and core functionality of the code
+2. Check for potential vulnerabilities or common pitfalls
+3. Ensure proper handling of invalid inputs or edge cases
+4. Verify important business logic or algorithmic correctness
+
+The number of tests should be proportional to the complexity and criticality of the code. For simple functions, a few tests might suffice. For complex components or those handling critical operations, more comprehensive testing may be necessary.
+
+Avoid generating tests for:
+1. Trivial cases that don't add value
+2. Implementation details that are likely to change
+3. Scenarios with very low probability or impact
+4. Redundant cases that don't test unique aspects of the code
+
+Aim to create a balanced test suite that provides good coverage without unnecessary redundancy.
 """
 
 PYTHON_UNIT_TEST_PROMPT = """
@@ -36,6 +52,9 @@ Generate pytest-style unit tests for the Python {NODE_TYPE} named {NODE_NAME}:
 
 SOURCE CODE:
 ```
+{GLOBAL_DATA}
+
+
 {SOURCE_CODE}
 ```
 
@@ -57,6 +76,8 @@ Generate Jest-style unit tests for the JavaScript/TypeScript {NODE_TYPE} named {
 
 SOURCE CODE:
 ```
+{GLOBAL_DATA}
+
 {SOURCE_CODE}
 ```
 
@@ -81,6 +102,8 @@ Generate Jest and React Testing Library tests for the React component of type {N
 
 SOURCE CODE:
 ```
+{GLOBAL_DATA}
+
 {SOURCE_CODE}
 ```
 
@@ -103,6 +126,8 @@ Generate unit tests for the Rust {NODE_TYPE} named {NODE_NAME}:
 
 SOURCE CODE:
 ```
+{GLOBAL_DATA}
+
 {SOURCE_CODE}
 ```
 
@@ -130,6 +155,8 @@ Review the unit tests for the {NODE_TYPE} named {NODE_NAME}. Follow these steps:
 
 2. COMPARE WITH SOURCE CODE:
    ```
+   {GLOBAL_DATA}
+   
    {SOURCE_CODE}
    ```
 
