@@ -33,10 +33,11 @@ LOGLEVEL = os.environ.get("LOG_LEVEL", "INFO").upper()
 logging.basicConfig(
     level=LOGLEVEL, format="%(asctime)s - %(name)s - %(levelname)s - %(message)s"
 )
+logger = logging.getLogger(__name__)
 
 
 class LLMProvider:
-    DEFAULT_MODEL = "gpt-3.5-turbo-1106"
+    DEFAULT_MODEL = "gpt-4o-mini"
     DEFAULT_MAX_TOKENS = 4000
     DEFAULT_TEMPERATURE = 0
     DEFAULT_MODEL_CONFIG = {"model": DEFAULT_MODEL}
@@ -78,11 +79,13 @@ class LLMProvider:
                 }
             ]
 
+    def set_system_prompt(self, system_prompt):
+        self.system_prompt = system_prompt
+
     def _setup_provider(self) -> None:
         provider_kwargs = {
             "model_list": self.models,
             "allowed_fails": 1,
-            "enable_pre_call_checks": True,
             "routing_strategy": "simple-shuffle",
         }
 
@@ -156,7 +159,6 @@ class LLMProvider:
             custom_model = {"model": model}
         if "temperature" not in custom_model:
             custom_model["temperature"] = self.default_temperature
-
         response = self.provider.completion(
             messages=messages, user=user, **custom_model
         )
@@ -189,7 +191,7 @@ class LLMProvider:
         self.model = response["model"]
         return response, response["usage"]
 
-    @retry(max_attempts=3, delay=1)
+    @retry(max_attempts=3, delay=0.1)
     def chat_completion_with_json(
         self,
         prompt,
@@ -205,10 +207,11 @@ class LLMProvider:
             custom_model=custom_model,
             messages=messages,
         )
+        # logger.info(f"completiong response: {response}")
         response = extract_json(response)
         return response, usage
 
-    @retry(max_attempts=3, delay=1)
+    @retry(max_attempts=3, delay=0.1)
     def chat_completion_with_retry(
         self,
         prompt,
@@ -233,7 +236,12 @@ class LLMProvider:
             {"role": "user", "content": PROMPT},
         ]
         token_count = litellm.token_counter(model=self.model, messages=messages)
-        max_tokens = litellm.get_max_tokens(self.model)
+        if token_count is None:
+            token_count = litellm.token_counter(model=self.DEFAULT_MODEL, text=PROMPT)
+        try:
+            max_tokens = litellm.get_max_tokens(self.model)
+        except Exception:
+            max_tokens = DEFAULT_MAX_TOKENS
         if not max_tokens:
             max_tokens = DEFAULT_MAX_TOKENS
         return token_count <= max_tokens * percentage
@@ -243,7 +251,10 @@ class LLMProvider:
     ) -> int:
         if not model:
             model = self.model
-        max_tokens = litellm.get_max_tokens(model)
+        try:
+            max_tokens = litellm.get_max_tokens(model)
+        except Exception:
+            max_tokens = DEFAULT_MAX_TOKENS
         used_tokens = litellm.token_counter(model=model, text=message)
         if max_tokens:
             return int(max_tokens * percentage) - used_tokens
