@@ -5,7 +5,6 @@ from kaizen.helpers import parser
 from kaizen.llms.provider import LLMProvider
 from kaizen.llms.prompts.code_review_prompts import (
     CODE_REVIEW_PROMPT,
-    FILE_CODE_REVIEW_PROMPT,
     PR_REVIEW_EVALUATION_PROMPT,
     CODE_REVIEW_SYSTEM_PROMPT,
 )
@@ -92,13 +91,14 @@ class ReviewOutput:
     usage: Dict[str, int]
     model_name: str
     cost: Dict[str, float]
+    file_count: int
 
 
 class CodeReviewer:
     def __init__(self, llm_provider: LLMProvider, default_model="default"):
         self.logger = logging.getLogger(__name__)
         self.provider = llm_provider
-        self.provider.system_prompt = CODE_REVIEW_SYSTEM_PROMPT
+        self.provider.set_system_prompt(CODE_REVIEW_SYSTEM_PROMPT)
         self.default_model = default_model
         self.total_usage = {
             "prompt_tokens": 0,
@@ -119,6 +119,7 @@ class CodeReviewer:
             CODE_DIFF=parser.patch_to_combined_chunks(
                 diff_text, ignore_deletions=self.ignore_deletions
             ),
+            CODE_REVIEW_PROMPT=self.custom_rules,
         )
         return self.provider.is_inside_token_limit(PROMPT=prompt)
 
@@ -134,13 +135,18 @@ class CodeReviewer:
         ignore_deletions=False,
         custom_context: str = "",
         check_sensetive: bool = False,
+        custom_rules: str = "",
     ) -> ReviewOutput:
         self.ignore_deletions = ignore_deletions
+        self.files_processed = 0
+        self.custom_rules = custom_rules
         prompt = (
             CODE_REVIEW_PROMPT.format(
                 CODE_DIFF=parser.patch_to_combined_chunks(
                     diff_text, self.ignore_deletions
                 ),
+                CUSTOM_RULES="Always mark issues that violate the following rules with a severity of 8 or higher (high and above):"
+                + self.custom_rules,
             )
             + custom_context
         )
@@ -180,6 +186,7 @@ class CodeReviewer:
             issues=reviews,
             code_quality=code_quality,
             cost={"prompt_cost": prompt_cost, "completion_cost": completion_cost},
+            file_count=self.files_processed,
         )
 
     def _process_full_diff(
@@ -237,22 +244,24 @@ class CodeReviewer:
         custom_context: str,
     ) -> Generator[Optional[Tuple[List[Dict], Optional[float]]], None, None]:
         combined_diff_data = ""
-        available_tokens = self.provider.available_tokens(FILE_CODE_REVIEW_PROMPT)
+        available_tokens = self.provider.available_tokens(CODE_REVIEW_PROMPT)
+        diff_parts = []
         for file in pull_request_files:
             patch_details = file.get("patch")
             filename = file.get("filename", "").replace(" ", "")
 
-            if (
-                filename.split(".")[-1] not in parser.EXCLUDED_FILETYPES
-                and patch_details is not None
-            ):
-                temp_prompt = (
-                    combined_diff_data
-                    + f"\n---->\nFile Name: {filename}\nPatch Details: {parser.patch_to_combined_chunks(patch_details, self.ignore_deletions)}"
+            if not parser.should_ignore_file(filename) and patch_details is not None:
+                self.files_processed += 1
+                diff_parts.append(
+                    f"\n---->\nFile Name: {filename}\nPatch Details:\n{parser.patch_to_combined_chunks(patch_details, self.ignore_deletions)}"
                 )
 
-                if available_tokens - self.provider.get_token_count(temp_prompt) > 0:
-                    combined_diff_data = temp_prompt
+                if (
+                    available_tokens
+                    - self.provider.get_token_count("".join(diff_parts))
+                    > 0
+                ):
+                    combined_diff_data = "".join(diff_parts)
                     continue
 
                 yield self._process_file_chunk(
@@ -263,11 +272,13 @@ class CodeReviewer:
                     reeval_response,
                     custom_context,
                 )
-                combined_diff_data = f"\n---->\nFile Name: {filename}\nPatch Details: {parser.patch_to_combined_chunks(patch_details,  self.ignore_deletions)}"
+                diff_parts = [
+                    f"\n---->\nFile Name: {filename}\nPatch Details: {parser.patch_to_combined_chunks(patch_details,  self.ignore_deletions)}"
+                ]
 
-        if combined_diff_data:
+        if diff_parts:
             yield self._process_file_chunk(
-                combined_diff_data,
+                "".join(diff_parts),
                 pull_request_title,
                 pull_request_desc,
                 user,
@@ -289,8 +300,10 @@ class CodeReviewer:
         if not diff_data:
             return None
         prompt = (
-            FILE_CODE_REVIEW_PROMPT.format(
-                FILE_PATCH=diff_data,
+            CODE_REVIEW_PROMPT.format(
+                CODE_DIFF=diff_data,
+                CUSTOM_RULES="Always mark issues that violate the following rules with a severity of 8 or higher (high and above):"
+                + self.custom_rules,
             )
             + custom_context
         )
